SystemOrganization addCategory: #ConfigurationOfSpec!

Object subclass: #ConfigurationOfSpec
	instanceVariableNames: 'project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfSpec'!

!ConfigurationOfSpec commentStamp: '<historical>' prior: 0!
A ConfigurationOfSpec is a class to properly load Specs.

ConfigurationOfSpec project load: #stable!

!ConfigurationOfSpec class methodsFor: 'private' stamp: ''!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSpec class methodsFor: 'private' stamp: ''!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfSpec class methodsFor: 'private' stamp: ''!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSpec class methodsFor: 'loading' stamp: ''!
loadBasic

	(self project version: #stable) load: 'basic'! !

!ConfigurationOfSpec class methodsFor: 'loading' stamp: ''!
loadCore

	(self project version: #stable) load: 'core'! !

!ConfigurationOfSpec class methodsFor: 'loading' stamp: ''!
loadDefault

	(self project version: #stable) load: 'default'! !

!ConfigurationOfSpec class methodsFor: 'loading' stamp: ''!
loadFull

	(self project version: #stable) load: 'full'! !

!ConfigurationOfSpec class methodsFor: 'private' stamp: ''!
project

	^self new project! !

!ConfigurationOfSpec methodsFor: 'baselines' stamp: ''!
baseline10: spec 
	<version: '1.0-baseline'>
	

	spec for: #pharo do: [
		
		"Info"
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Spec'.
		
		"Our own stuff"
		spec 
			package: 'Spec-Core';
			package: 'Spec-Examples' with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Tests' with: [ spec requires: #('Spec-Core') ];
			package: 'Spec-Tools'  with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Widgets'.
			
		spec 
			group: 'basic' with: #('core' 'Spec-Widgets');
			group: 'core' with: #('Spec-Core' 'Spec-Tests');
			group: 'full' with: #('default' 'Spec-Examples');
			group: 'default' with: #('basic' 'Spec-Tools') ]! !

!ConfigurationOfSpec methodsFor: 'baselines' stamp: ''!
baseline20: spec 
	<version: '2.0-baseline'>
	

	spec for: #pharo do: [
		
		"Info"
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Spec'.
		
		"Our own stuff"
		spec 
			package: 'Spec-Builder' with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Core';
			package: 'Spec-Examples' with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Tests' with: [ spec requires: #('Spec-Core') ];
			package: 'Spec-Tools'  with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Widgets'.
			
		spec 
			group: 'basic' with: #('core' 'Spec-Widgets');
			group: 'core' with: #('Spec-Core' 'Spec-Tests');
			group: 'full' with: #('default' 'Spec-Examples');
			group: 'default' with: #('basic' 'Spec-Tools');
			group: 'builder' with: #('basic' 'Spec-Builder') ]! !

!ConfigurationOfSpec methodsFor: 'baselines' stamp: 'BenjaminVanRyseghem 3/26/2012 13:03'!
baseline30: spec 
	<version: '3.0-baseline'>
	
	spec for: #pharo do: [
		
		"Info"
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Spec'.
		
		"Our own stuff"
		spec 
			package: 'Spec-Builder' with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Core' with: [ spec requires: #('Spec-Bindings') ];
			package: 'Spec-Bindings';
			package: 'Spec-Examples' with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Tests' with: [ spec requires: #('Spec-Core') ];
			package: 'Spec-Tools'  with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Widgets'.
			
		spec 
			group: 'basic' with: #('core' 'Spec-Widgets');
			group: 'core' with: #('Spec-Core' 'Spec-Tests');
			group: 'full' with: #('default' 'Spec-Examples');
			group: 'default' with: #('basic' 'Spec-Tools');
			group: 'builder' with: #('basic' 'Spec-Builder') ]! !

!ConfigurationOfSpec methodsFor: 'baselines' stamp: 'BenjaminVanRyseghem 6/21/2012 11:01'!
baseline40: spec 
	<version: '4.0-baseline'>
	
	spec for: #pharo do: [
		
		"Info"
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Spec'.
		
		"Our own stuff"
		spec
			package: 'Spec-Layout'; 
			package: 'Spec-Builder' with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Core' with: [ spec requires: #('Spec-Bindings' 'Spec-Layout') ];
			package: 'Spec-Bindings';
			package: 'Spec-Examples' with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Tests' with: [ spec requires: #('Spec-Core') ];
			package: 'Spec-Tools'  with: [ spec requires: #('Spec-Core' 'Spec-Widgets') ];
			package: 'Spec-Widgets'.
			
		spec 
			group: 'basic' with: #('core' 'Spec-Widgets');
			group: 'core' with: #('Spec-Core' 'Spec-Tests');
			group: 'full' with: #('default' 'Spec-Examples');
			group: 'default' with: #('basic' 'Spec-Tools');
			group: 'builder' with: #('basic' 'Spec-Builder') ]! !

!ConfigurationOfSpec methodsFor: 'symbolics' stamp: 'BenjaminVanRyseghem 6/21/2012 11:01'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfSpec methodsFor: 'project' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfSpec methodsFor: 'symbolics' stamp: 'BenjaminVanRyseghem 6/21/2012 11:01'!
stable: spec
	<symbolicVersion: #stable>

	spec for: #'common' version: '1.0'.! !

!ConfigurationOfSpec methodsFor: 'versions' stamp: ''!
version01: spec
	<version: '0.1' imports: #('1.0-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '01 : First C0nfiguration';
			author: 'BenjaminVanRyseghem';
			timestamp: '2/23/2012 18:33'.
		
		spec 
			package: 'Spec-Examples' with: 'Spec-Examples-BenjaminVanRyseghem.1';
			package: 'Spec-Core' with: 'Spec-Core-BenjaminVanRyseghem.5';
			package: 'Spec-Tests' with: 'Spec-Tests-BenjaminVanRyseghem.1';
			package: 'Spec-Tools' with: 'Spec-Tools-BenjaminVanRyseghem.5';
			package: 'Spec-Widgets' with: 'Spec-Widgets-BenjaminVanRyseghem.2']! !

!ConfigurationOfSpec methodsFor: 'versions' stamp: ''!
version02: spec
	<version: '0.2' imports: #('2.0-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '02 : Introduction of the builder';
			author: 'BenjaminVanRyseghem';
			timestamp: '2/28/2012 22:52'.
		
		spec 
			package: 'Spec-Builder' with:'Spec-Builder-BenjaminVanRyseghem.4';
			package: 'Spec-Core' with: 'Spec-Core-BenjaminVanRyseghem.8';
			package: 'Spec-Examples' with: 'Spec-Examples-BenjaminVanRyseghem.1';
			package: 'Spec-Tests' with: 'Spec-Tests-BenjaminVanRyseghem.2';
			package: 'Spec-Tools' with: 'Spec-Tools-BenjaminVanRyseghem.6';
			package: 'Spec-Widgets' with: 'Spec-Widgets-BenjaminVanRyseghem.5']! !

!ConfigurationOfSpec methodsFor: 'versions' stamp: 'BenjaminVanRyseghem 5/12/2012 17:40'!
version03: spec
	<version: '0.3' imports: #('3.0-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '03 : Introduction of bindings';
			author: 'BenjaminVanRyseghem';
			timestamp: '3/26/2012 13:02'.
		
		spec 
			package: 'Spec-Bindings' with: 'Spec-Bindings-BenjaminVanRyseghem.4';
			package: 'Spec-Builder' with:'Spec-Builder-BenjaminVanRyseghem.6';
			package: 'Spec-Core' with: 'Spec-Core-BenjaminVanRyseghem.17';
			package: 'Spec-Examples' with: 'Spec-Examples-BenjaminVanRyseghem.4';
			package: 'Spec-Tests' with: 'Spec-Tests-BenjaminVanRyseghem.3';
			package: 'Spec-Tools' with: 'Spec-Tools-BenjaminVanRyseghem.22';
			package: 'Spec-Widgets' with: 'Spec-Widgets-BenjaminVanRyseghem.24']! !

!ConfigurationOfSpec methodsFor: 'versions' stamp: 'BenjaminVanRyseghem 6/8/2012 11:50'!
version04: spec
	<version: '0.4' imports: #('3.0-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '04 : Modification according to the IWST paper';
			author: 'BenjaminVanRyseghem';
			timestamp: '6/4/2012 17:30'.
		
		spec 
			package: 'Spec-Bindings' with: 'Spec-Bindings-bvr.6';
			package: 'Spec-Builder' with:'Spec-Builder-bvr.7';
			package: 'Spec-Core' with: 'Spec-Core-BenjaminVanRyseghem.30';
			package: 'Spec-Examples' with: 'Spec-Examples-BenjaminVanRyseghem.6';
			package: 'Spec-Presenter' with: 'Spec-Presenter-BenjaminVanRyseghem.1';
			package: 'Spec-Tests' with: 'Spec-Tests-BenjaminVanRyseghem.10';
			package: 'Spec-Tools' with: 'Spec-Tools-BenjaminVanRyseghem.30';
			package: 'Spec-Widgets' with: 'Spec-Widgets-BenjaminVanRyseghem.36']! !

!ConfigurationOfSpec methodsFor: 'versions' stamp: 'BenjaminVanRyseghem 6/26/2012 17:54'!
version10: spec
	<version: '1.0' imports: #('4.0-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '1.0 : Modification according to the IWST paper';
			author: 'BenjaminVanRyseghem';
			timestamp: '6/21/2012 10:56'.
		
		spec 
			package: 'Spec-Bindings' with: 'Spec-Bindings-bvr.6';
			package: 'Spec-Builder' with:'Spec-Builder-BenjaminVanRyseghem.8';
			package: 'Spec-Core' with: 'Spec-Core-BenjaminVanRyseghem.34';
			package: 'Spec-Examples' with: 'Spec-Examples-BenjaminVanRyseghem.7';
			package: 'Spec-Layout' with: 'Spec-Layout-BenjaminVanRyseghem.3';
			package: 'Spec-Tests' with: 'Spec-Tests-BenjaminVanRyseghem.11';
			package: 'Spec-Tools' with: 'Spec-Tools-BenjaminVanRyseghem.31';
			package: 'Spec-Widgets' with: 'Spec-Widgets-BenjaminVanRyseghem.42']! !
